View source: R/huge.inference.R
| huge.inference | R Documentation |
Implements the inference for high dimensional graphical models, including Gaussian and Nonparanormal graphical models We consider the problems of testing the presence of a single edge and the hypothesis is that the edge is absent.
huge.inference(data, T, adj, alpha = 0.05, type = "Gaussian", method = "score")
data |
A finite numeric |
T |
A finite |
adj |
A finite numeric or logical |
alpha |
The significance level in |
type |
The type of input data. There are 2 options: |
method |
For a Nonparanormal model, the test method: |
For Nonparanormal graphical model we provide Score test method and Wald Test. However it is really slow for inferencing on Nonparanormal model, especially for large data. Gaussian inference supports one variable, while Nonparanormal inference requires at least two. Nonparanormal score-test diagonal p-values do not represent edges and may be undefined; every tested off-diagonal p-value must be finite.
An object is returned:
data |
The |
p |
The |
error |
The type I error of hypothesis at alpha significance level. |
1.Q Gu, Y Cao, Y Ning, H Liu. Local and global inference for high dimensional nonparanormal graphical models.
2.J Jankova, S Van De Geer. Confidence intervals for high-dimensional inverse covariance estimation. Electronic Journal of Statistics, 2015.
huge, and huge-package.
#generate data
L = huge.generator(n = 50, d = 12, graph = "hub", g = 4)
#graph path estimation using glasso
est = huge(L$data, method = "glasso")
#inference of Gaussian graphical model at 0.05 significance level
T = tail(est$icov, 1)[[1]]
out1 = huge.inference(L$data, T, L$theta)
#inference of Nonparanormal graphical model using score test at 0.05 significance level
T = tail(est$icov, 1)[[1]]
out2 = huge.inference(L$data, T, L$theta, type = "Nonparanormal")
#inference of Nonparanormal graphical model using wald test at 0.05 significance level
T = tail(est$icov, 1)[[1]]
out3 = huge.inference(L$data, T, L$theta, type = "Nonparanormal", method = "wald")
#inference of Nonparanormal graphical model using wald test at 0.1 significance level
T = tail(est$icov, 1)[[1]]
out4 = huge.inference(L$data, T, L$theta, 0.1, type = "Nonparanormal", method = "wald")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.