Learn R Programming

huge (version 2.0.0)

huge.mb: Meinshausen & Buhlmann graph estimation

Description

See more details in huge

Usage

huge.mb(
  x,
  lambda = NULL,
  nlambda = NULL,
  lambda.min.ratio = NULL,
  scr = NULL,
  scr.num = NULL,
  idx.mat = NULL,
  sym = "or",
  verbose = TRUE,
  input.type = "auto"
)

Arguments

x

There are 2 options: (1) x is an n by d data matrix (2) a d by d sample covariance matrix. The program automatically identifies the input matrix by checking the symmetry. (n is the sample size and d is the dimension).

lambda

A numeric scalar or non-empty one-dimensional numeric input defining a finite, strictly positive, non-increasing regularization path; tied values are allowed. Leave lambda = NULL to generate a path from nlambda and lambda.min.ratio.

nlambda

The number of regularization/thresholding parameters. The default value is 20 for method = "ct" and 10 for method = "mb", "glasso" or "tiger".

lambda.min.ratio

If method = "mb", "glasso" or "tiger", it is the smallest value for lambda, as a fraction of the upperbound (MAX) of the regularization/thresholding parameter which makes all estimates equal to 0. The program can automatically generate lambda as a sequence of length = nlambda starting from MAX to lambda.min.ratio*MAX in log scale. If method = "ct", it is the largest sparsity level for estimated graphs. The program can automatically generate lambda as a sequence of length = nlambda, which makes the sparsity level of the graph path increases from 0 to lambda.min.ratio evenly.The default value is 0.1 when method = "mb", "glasso" or "tiger", and 0.05 when method = "ct".

scr

If scr = TRUE, the lossy screening rule is applied to preselect the neighborhood before the graph estimation. The default value is FALSE.

scr.num

The neighborhood size after the lossy screening rule (the number of remaining neighbors per node). It must be an integer between 1 and d - 1. ONLY applicable when scr = TRUE. The default value is n-1. An alternative value is n/log(n). ONLY applicable when scr = TRUE and method = "mb".

idx.mat

A scr.num by d index matrix for screening. Column m must contain distinct, zero-based indices in 0:(d - 1) and must exclude the response index m - 1.

sym

Symmetrize the output graphs. If sym = "and", the edge between node i and node j is selected ONLY when both node i and node j are selected as neighbors for each other. If sym = "or", the edge is selected when either node i or node j is selected as the neighbor for each other. The default value is "or". ONLY applicable when method = "mb" or "tiger".

verbose

If verbose = FALSE, tracing information printing is disabled. The default value is TRUE.

input.type

How to interpret x: "auto" preserves symmetry-based detection, "data" forces an observation matrix, and "covariance" requires a square covariance or correlation matrix.

See Also

huge, and huge-package.