print.roc: Print function for S3 class "roc"

View source: R/huge.roc.R

print.rocR Documentation

Print function for S3 class "roc"

Description

Print the information about true positive rates, false positive rates, the area under curve and maximum F1 score.

Usage

## S3 method for class 'roc'
print(x, ...)

Arguments

x

An object with S3 class "roc".

...

System reserved (No specific usage)

See Also

huge.roc


huge documentation built on March 11, 2026, 5:07 p.m.