print.sim: Print function for S3 class "sim"

View source: R/huge.generator.R

print.simR Documentation

Print function for S3 class "sim"

Description

Print the information about the sample size, the dimension, the pattern and sparsity of the true graph structure.

Usage

## S3 method for class 'sim'
print(x, ...)

Arguments

x

An object with S3 class "sim".

...

System reserved (No specific usage)

See Also

huge.generator


huge documentation built on March 11, 2026, 5:07 p.m.