Learn R Programming

huge (version 2.0.0)

huge.inference: Graph inference

Description

Implements the inference for high dimensional graphical models, including Gaussian and Nonparanormal graphical models We consider the problems of testing the presence of a single edge and the hypothesis is that the edge is absent.

Usage

huge.inference(data, T, adj, alpha = 0.05, type = "Gaussian", method = "score")

Value

An object is returned:

data

The n by d data matrix from the input.

p

The d by d p-value matrix of hypothesis.

error

The type I error of hypothesis at alpha significance level.

Arguments

data

A finite numeric n by d data matrix with at least two observations and no constant columns.

T

A finite d by d estimate of the inverse correlation matrix with a positive diagonal.

adj

A finite numeric or logical d by d adjacency matrix corresponding to the graph.

alpha

The significance level in (0, 1]. The default value is 0.05.

type

The type of input data. There are 2 options: "Gaussian" and "Nonparanormal". The default value is "Gaussian".

method

For a Nonparanormal model, the test method: "score" or "wald". The default is "score". Ignored for Gaussian inference.

Details

For Nonparanormal graphical model we provide Score test method and Wald Test. However it is really slow for inferencing on Nonparanormal model, especially for large data. Gaussian inference supports one variable, while Nonparanormal inference requires at least two. Nonparanormal score-test diagonal p-values do not represent edges and may be undefined; every tested off-diagonal p-value must be finite.

References

1.Q Gu, Y Cao, Y Ning, H Liu. Local and global inference for high dimensional nonparanormal graphical models.
2.J Jankova, S Van De Geer. Confidence intervals for high-dimensional inverse covariance estimation. Electronic Journal of Statistics, 2015.

See Also

huge, and huge-package.

Examples

Run this code
#generate data
L = huge.generator(n = 50, d = 12, graph = "hub", g = 4)

#graph path estimation using glasso
est = huge(L$data, method = "glasso")

#inference of Gaussian graphical model at 0.05 significance level
T = tail(est$icov, 1)[[1]]
out1 = huge.inference(L$data, T, L$theta)

#inference of Nonparanormal graphical model using score test at 0.05 significance level
T = tail(est$icov, 1)[[1]]
out2 = huge.inference(L$data, T, L$theta, type = "Nonparanormal")

#inference of Nonparanormal graphical model using wald test at 0.05 significance level
T = tail(est$icov, 1)[[1]]
out3 = huge.inference(L$data, T, L$theta, type = "Nonparanormal", method = "wald")

#inference of Nonparanormal graphical model using wald test at 0.1 significance level
T = tail(est$icov, 1)[[1]]
out4 = huge.inference(L$data, T, L$theta, 0.1, type = "Nonparanormal", method = "wald")

Run the code above in your browser using DataLab