See more details in huge
huge.mb(
x,
lambda = NULL,
nlambda = NULL,
lambda.min.ratio = NULL,
scr = NULL,
scr.num = NULL,
idx.mat = NULL,
sym = "or",
verbose = TRUE
)There are 2 options: (1) x is an n by d data matrix (2) a d by d sample covariance matrix. The program automatically identifies the input matrix by checking the symmetry. (n is the sample size and d is the dimension).
A sequence of decreasing positive numbers to control the regularization when method = "mb", "glasso" or "tiger", or the thresholding in method = "ct". Typical usage is to leave the input lambda = NULL and have the program compute its own lambda sequence based on nlambda and lambda.min.ratio. Users can also specify a sequence to override this. When method = "mb", "glasso" or "tiger", use with care - it is better to supply a decreasing sequence values than a single (small) value.
The number of regularization/thresholding parameters. The default value is 30 for method = "ct" and 10 for method = "mb", "glasso" or "tiger".
If method = "mb", "glasso" or "tiger", it is the smallest value for lambda, as a fraction of the upperbound (MAX) of the regularization/thresholding parameter which makes all estimates equal to 0. The program can automatically generate lambda as a sequence of length = nlambda starting from MAX to lambda.min.ratio*MAX in log scale. If method = "ct", it is the largest sparsity level for estimated graphs. The program can automatically generate lambda as a sequence of length = nlambda, which makes the sparsity level of the graph path increases from 0 to lambda.min.ratio evenly.The default value is 0.1 when method = "mb", "glasso" or "tiger", and 0.05 when method = "ct".
If scr = TRUE, the lossy screening rule is applied to preselect the neighborhood before the graph estimation. The default value is FALSE.
The neighborhood size after the lossy screening rule (the number of remaining neighbors per node). ONLY applicable when scr = TRUE. The default value is n-1. An alternative value is n/log(n). ONLY applicable when scr = TRUE and method = "mb".
Index matrix for screening.
Symmetrize the output graphs. If sym = "and", the edge between node i and node j is selected ONLY when both node i and node j are selected as neighbors for each other. If sym = "or", the edge is selected when either node i or node j is selected as the neighbor for each other. The default value is "or". ONLY applicable when method = "mb" or "tiger".
If verbose = FALSE, tracing information printing is disabled. The default value is TRUE.
huge, and huge-package.