huge.scr(x, ind.group = NULL, scr.num = NULL, approx = FALSE, nlambda = 30,
lambda.min.ratio = 0.1, lambda = NULL, verbose = TRUE)n by d data matrix representing n observations in d dimensionsk dimensional vector indexing a subset of all d variables. ONLY applicable when estimating a subgraph of the whole graph. The default value is c(1:d).n-1 when d>n and d-1 (equivalent to disabling the GSS) when n>=d. An alternative value is n/log(n)approx = FALSE, the GSS is implemented. If approx = TRUE, the GACT is implemented. The default value is approx = FALSE.lambda = NULL and have the program compute its own lambda sequence based on nlambda and lamb30.ONLY application when approx = TRUE.lambda, as a fraction of the uppperbound (MAX) of the thresholding parameter which makes all estimates equal to 0. The program can automatically generate lambda as a sequence of leverbose = FALSE, printing the tracing information is disabled. The default value is TRUE.lambda. ONLY applicable when approx = TRUE.approx = TRUE.approx = TRUE.scr.num by k matrix is returned. Each column corresponds to a variable in ind.group and contains the indices of the remaining neighbors after the graph screening. ONLY applicable when approx = FALSE.huge and huge-package# generate data
L = huge.generator(graph = "hub", g = 5)
ind.group = c(1:30)
# the Graph Sure Screening (GSS)
out.scr = huge.scr(L$data, ind.group = ind.group)
summary(out.scr)
# the Graph Approximation via Correlation Threholding (GACT)
out.approx = huge.scr(L$data, approx = TRUE, nlambda = 20)
summary(out.approx)
plot(out.approx)
out.scr = huge.scr(L$data, ind.group = ind.group, approx = TRUE)
huge.plot(out.scr$path[[15]])Run the code above in your browser using DataLab