huge.scr(x, ind.group = NULL, scr.num = NULL, approx = FALSE, n.lambda = 30,
lambda.min = 1e-4, lambda = NULL, verbose = TRUE)n by d data matrix representing n observations in d dimensionsk dimensional vector indexing a subset of all d variables. Only applicable when estimating a subgraph of the whole graph. The default value is c(1:d).n-1 when d>n and d-1 (equivalent to disabling graph screening procedure) when n>=d. An alternativapprox = FALSE, the graph screening procedure is implemented. If approx = TRUE, Graph Estimation via Correlation Approximation (GECA) is implemented. The defaulty value is approx = FALSE.lambda = NULL and have the program compute its own lambda sequence based on n.lambda and lambda.30.Only application when approx = TRUE.lambda, as a fraction of the uppperbound (MAX) of the thresholding parameter which makes all estimates equal to 0. The program can automatically generate lambda as a sequence of leverbose = FALSE, printing the tracing information is disabled. The default value is TRUE.lambda. Only applicable when approx = TRUE.approx = TRUE.approx = TRUE.scr.num by k matrix is returned. Each column corresponds to a variable in ind.group and contains the indices of the remaining neighbors after the graph screening. Only applicable when approx = FALSE.huge and huge-package#generate data
n = 50
L = huge.generator(n = n, d = 100, graph = "hub")
#subset indices
ind.group = c(1:40)
#graph screening for a subset of variables
out.scr = huge.scr(L$data, ind.group = ind.group)
summary(out.scr)
#graph screening using alternative neighborhood size
scr.num = n/log(n)
ind.mat = huge.scr(L$data, scr.num = scr.num)$ind.mat
#GECA
out.approx = huge.scr(L$data, approx = TRUE, n.lambda = 10)
summary(out.approx)
plot(out.approx)Run the code above in your browser using DataLab